(logical, single value) if TRUE, probabilities are given as \(\log(p)\). Default is FALSE.
lower.tail
(logical, single value) if TRUE (default), probabilities are \(P(X\le x)\); otherwise \(P(X>x)\).
Value
dlaplace gives the density, plaplace gives the distribution function, qlaplace gives the quantile function, and rlaplace generates random deviates.
The length of the result is determined by n for rnorm, and is the maximum of the lengths of the numerical arguments for the other functions.
Details
The laplace distribution with shape parameter \(\mu>0\) and scale parameter \(b>0\) has density
$$f(x) = \frac{1}{2b}\exp(-\frac{|x-\mu|}{b}), \quad x \in R.$$